@@ -51,6 +51,15 @@ return array(
 					'default' => '/var/customers/mail/',
 					'save_method' => 'storeSettingField',
 					),
+				'system_vmail_maildirname' => array(
+					'label' => $lng['serversettings']['vmail_maildirname'],
+					'settinggroup' => 'system',
+					'varname' => 'vmail_maildirname',
+					'type' => 'string',
+					'string_type' => 'dir',
+					'default' => 'Maildir',
+					'save_method' => 'storeSettingField',
+					),
 				'panel_sendalternativemail' => array(
 					'label' => $lng['serversettings']['sendalternativemail'],
 					'settinggroup' => 'panel',
@@ -90,9 +99,17 @@ return array(
 					'type' => 'hidden',
 					'default' => 0,
 					),
+				'system_catchall_enabled' => array(
+					'label' => $lng['serversettings']['catchall_enabled'],
+					'settinggroup' => 'catchall',
+					'varname' => 'catchall_enabled',
+					'type' => 'bool',
+					'default' => true,
+					'save_method' => 'storeSettingResetCatchall',
+					),
 				),
 			),
 		),
 	);
 
-?>
\ No newline at end of file
+?>
