@@ -196,7 +196,10 @@ elseif($page == 'domains')
 				$result = $db->query("DELETE FROM `" . TABLE_PANEL_DOMAINS . "` WHERE `customerid`='" . (int)$userinfo['customerid'] . "' AND `id`='" . (int)$id . "'");
 				$result = $db->query("UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `subdomains_used`=`subdomains_used`-1 WHERE `customerid`='" . (int)$userinfo['customerid'] . "'");
 				inserttask('1');
+
+				// Using nameserver, insert a task which rebuilds the server config
 				inserttask('4');
+
 				redirectTo($filename, Array('page' => $page, 's' => $s));
 			}
 			else
@@ -249,8 +252,17 @@ elseif($page == 'domains')
 				if(!preg_match('/^https?\:\/\//', $path)
 				   || !validateUrl($idna_convert->encode($path)))
 				{
-					$path = $userinfo['documentroot'] . '/' . $path;
-					$path = makeCorrectDir($path);
+					// If path is empty or '/' and 'Use domain name as default value for DocumentRoot path' is enabled in settings,
+					// set default path to subdomain or domain name
+					if((($path == '') || ($path == '/'))
+						&& $settings['system']['documentroot_use_default_value'] == 1)
+					{
+						$path = makeCorrectDir($userinfo['documentroot'] . '/' . $completedomain);
+					}
+					else
+					{
+						$path = makeCorrectDir($userinfo['documentroot'] . '/' . $path);
+					}
 					if (strstr($path, ":") !== FALSE)
 					{
 						standard_error('pathmaynotcontaincolon');
@@ -329,8 +341,7 @@ elseif($page == 'domains')
 								`parentdomainid` = '" . (int)$domain_check['id'] . "', 
 								`isemaildomain` = '" . ($domain_check['subcanemaildomain'] == '3' ? '1' : '0') . "', 
 								`openbasedir` = '" . $db->escape($domain_check['openbasedir']) . "', 
-								`openbasedir_path` = '" . $db->escape($openbasedir_path) . "', 
-								`safemode` = '" . $db->escape($domain_check['safemode']) . "', 
+								`openbasedir_path` = '" . $db->escape($openbasedir_path) . "',
 								`speciallogfile` = '" . $db->escape($domain_check['speciallogfile']) . "', 
 								`specialsettings` = '" . $db->escape($domain_check['specialsettings']) . "', 
 								`ssl_redirect` = '" . $ssl_redirect . "', 
@@ -346,7 +357,10 @@ elseif($page == 'domains')
 					$result = $db->query("UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `subdomains_used`=`subdomains_used`+1 WHERE `customerid`='" . (int)$userinfo['customerid'] . "'");
 					$log->logAction(USR_ACTION, LOG_INFO, "added subdomain '" . $completedomain . "'");
 					inserttask('1');
+
+					// Using nameserver, insert a task which rebuilds the server config
 					inserttask('4');
+
 					redirectTo($filename, Array('page' => $page, 's' => $s));
 				}
 			}
@@ -378,7 +392,13 @@ elseif($page == 'domains')
 					}
 				}
 
-				#$ssl_redirect = makeyesno('ssl_redirect', '1', '0', $result['ssl_redirect']);
+				// check if we at least have one ssl-ip/port, #1179
+				$ssl_ipsandports = '';
+				$resultX = $db->query_first("SELECT COUNT(*) as countSSL FROM `panel_ipsandports` WHERE `ssl`='1'");
+				if (isset($resultX['countSSL']) && (int)$resultX['countSSL'] > 0) {
+					$ssl_ipsandports = 'notempty';
+				}
+
 				$openbasedir = makeoption($lng['domain']['docroot'], 0, NULL, true) . makeoption($lng['domain']['homedir'], 1, NULL, true);
 				$pathSelect = makePathfield($userinfo['documentroot'], $userinfo['guid'], $userinfo['guid'], $settings['panel']['pathedit']);
 
@@ -421,8 +441,17 @@ elseif($page == 'domains')
 				if(!preg_match('/^https?\:\/\//', $path)
 				   || !validateUrl($idna_convert->encode($path)))
 				{
-					$path = $userinfo['documentroot'] . '/' . $path;
-					$path = makeCorrectDir($path);
+					// If path is empty or '/' and 'Use domain name as default value for DocumentRoot path' is enabled in settings,
+					// set default path to subdomain or domain name
+					if((($path == '') || ($path == '/'))
+						&& $settings['system']['documentroot_use_default_value'] == 1)
+					{
+						$path = makeCorrectDir($userinfo['documentroot'] . '/' . $result['domain']);
+					}
+					else
+					{
+						$path = makeCorrectDir($userinfo['documentroot'] . '/' . $path);
+					}
 					if (strstr($path, ":") !== FALSE)
 					{
 						standard_error('pathmaynotcontaincolon');
@@ -521,7 +550,10 @@ elseif($page == 'domains')
 						$log->logAction(USR_ACTION, LOG_INFO, "edited domain '" . $idna_convert->decode($result['domain']) . "'");
 						$result = $db->query("UPDATE `" . TABLE_PANEL_DOMAINS . "` SET `documentroot`='" . $db->escape($path) . "', `isemaildomain`='" . (int)$isemaildomain . "', `iswildcarddomain`='" . (int)$iswildcarddomain . "', `aliasdomain`=" . (($aliasdomain != 0 && $alias_check == 0) ? '\'' . $db->escape($aliasdomain) . '\'' : 'NULL') . ",`openbasedir_path`='" . $db->escape($openbasedir_path) . "', `ssl_redirect`='" . $ssl_redirect . "' WHERE `customerid`='" . (int)$userinfo['customerid'] . "' AND `id`='" . (int)$id . "'");
 						inserttask('1');
+
+						// Using nameserver, insert a task which rebuilds the server config
 						inserttask('4');
+
 					}
 
 					redirectTo($filename, Array('page' => $page, 's' => $s));
@@ -570,9 +602,13 @@ elseif($page == 'domains')
 					}
 				}
 
-				#$ssl_redirect = makeyesno('ssl_redirect', '1', '0', $result['ssl_redirect']);
-				#$iswildcarddomain = makeyesno('iswildcarddomain', '1', '0', $result['iswildcarddomain']);
-				#$isemaildomain = makeyesno('isemaildomain', '1', '0', $result['isemaildomain']);
+				// check if we at least have one ssl-ip/port, #1179
+				$ssl_ipsandports = '';
+				$resultX = $db->query_first("SELECT COUNT(*) as countSSL FROM `panel_ipsandports` WHERE `ssl`='1'");
+				if (isset($resultX['countSSL']) && (int)$resultX['countSSL'] > 0) {
+					$ssl_ipsandports = 'notempty';
+				}
+
 				$openbasedir = makeoption($lng['domain']['docroot'], 0, $result['openbasedir_path'], true) . makeoption($lng['domain']['homedir'], 1, $result['openbasedir_path'], true);
 
 				$result_ipandport = $db->query_first("SELECT `ip` FROM `".TABLE_PANEL_IPSANDPORTS."` WHERE `id`='".(int)$result['ipandport']."'");
