@@ -26,7 +26,7 @@
  */
 function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 {
-	global $settings, $lng, $db;
+	global $settings, $lng, $db, $theme;
 
 	if(versionInUpdate($current_version, '0.9.4-svn2'))
 	{
@@ -73,9 +73,9 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 		$description = 'You can define a default support-ticket priority level which is pre-selected for new support-tickets.';
 		$question = '<strong>Which should be the default ticket-priority?:</strong>&nbsp;';
 		$question .= '<select name="update_deftic_priority">';
-		$priorities = makeoption($lng['ticket']['unf_high'], '1', '2');
-		$priorities.= makeoption($lng['ticket']['unf_normal'], '2', '2');
-		$priorities.= makeoption($lng['ticket']['unf_low'], '3', '2');
+		$priorities = makeoption($lng['ticket']['high'], '1', '2');
+		$priorities.= makeoption($lng['ticket']['normal'], '2', '2');
+		$priorities.= makeoption($lng['ticket']['low'], '3', '2');
 		$question .= $priorities.'</select>';
 		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 	}
@@ -417,16 +417,90 @@ function parseAndOutputPreconfig(&$has_preconfig, &$return, $current_version)
 	}
 
 	if(versionInUpdate($current_version, '0.9.18-svn2'))
-	{       
+	{
 		$has_preconfig = true;
 		$description = 'As you can (obviously) see, Froxlor now comes with a new theme. You also have the possibility to switch back to "Classic" if you want to.'; 
 		$question = '<strong>Select default panel theme:</strong>&nbsp;';
 		$question.= '<select name="update_default_theme">';
 		$themes = getThemes();
-		foreach($themes as $theme) {
-			$question.= makeoption($theme, $theme, 'Froxlor');
+		foreach($themes as $cur_theme) // $theme is already in use
+		{
+			$question.= makeoption($cur_theme, $cur_theme, 'Froxlor');
 		}
 		$question.= '</select>';
 		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
 	}
+
+	if(versionInUpdate($current_version, '0.9.28-svn4'))
+	{
+		$has_preconfig = true;
+		$description = 'This version introduces a lot of profound changes:';
+		$description .= '<br /><ul><li>Improving the whole template system</li><li>Full UTF-8 support</li><li><strong>Removing support for the former default theme \'Classic\'</strong></li></ul>';
+		$description .= '<br /><br />Notice: This update will <strong>alter your Froxlor database to use UTF-8</strong> as default charset. ';
+		$description .= 'Even though this is already tested, we <span style="color:#ff0000;font-weight:bold;">strongly recommend</span> to ';
+		$description .= 'test this update in a testing environment using your existing data.<br /><br />';
+
+		$question = '<strong>Select your preferred Classic Theme replacement:</strong>&nbsp;';
+		$question.= '<select name="classic_theme_replacement">';
+		$themes = getThemes();
+		foreach($themes as $cur_theme)
+		{
+			$question.= makeoption($cur_theme, $cur_theme, 'Froxlor');
+		}
+		$question.= '</select>';
+
+		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+	}
+
+	if (versionInUpdate($current_version, '0.9.28-svn6')) {
+
+		if ($settings['system']['webserver'] == 'apache2') {
+			$has_preconfig = true;
+			$description = 'Froxlor now supports the new Apache 2.4. Please be aware that you need to load additional apache-modules in ordner to use it.<br />';
+			$description.= '<pre>LoadModule authz_core_module modules/mod_authz_core.so
+LoadModule authz_host_module modules/mod_authz_host.so</pre><br />';
+			$question = '<strong>Do you want to enable the Apache-2.4 modification?:</strong>&nbsp;';
+			$question.= makeyesno('update_system_apache24', '1', '0', '0');
+			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+		} elseif ($settings['system']['webserver'] == 'nginx') {
+			$has_preconfig = true;
+			$description = 'The path to nginx\'s fastcgi_params file is now customizable.<br /><br />';
+			$question = '<strong>Please enter full path to you nginx/fastcgi_params file (including filename):</strong>&nbsp;';
+			$question.= '<input type="text" class="text" name="nginx_fastcgi_params" value="/etc/nginx/fastcgi_params" />';
+			eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");			
+		}
+	}
+
+	if (versionInUpdate($current_version, '0.9.28-rc2')) {
+
+		$has_preconfig = true;
+
+		$description  = 'This version adds an option to append the domain-name to the document-root for domains and subdomains.<br />';
+		$description .= 'You can enable or disable this feature anytime from settings -> system settings.<br />';
+
+		$question = '<strong>Do you want to automatically append the domain-name to the documentroot of newly created domains?:</strong>&nbsp;';
+		$question.= makeyesno('update_system_documentroot_use_default_value', '1', '0', '0');
+
+		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+	}
+
+	if (versionInUpdate($current_version, '0.9.28')) {
+
+		$has_preconfig = true;
+		// just an information about the new sendmail parameter (#1134)
+		$description  = 'Froxlor changed the default parameter-set of sendmail (php.ini)<br />';
+		$description .= 'sendmail_path = "/usr/sbin/sendmail -t <strong>-i</strong> -f {CUSTOMER_EMAIL}"<br /><br />';
+		$description .= 'If you don\'t have any problems with sending mails, you don\'t need to change this';
+		if ($this->_settings['system']['mod_fcgid'] == '1'
+				|| $this->_settings['phpfpm']['enabled'] == '1'
+		) {
+			// information about removal of php's safe_mode
+			$description .= '<br /><br />The php safe_mode flag has been removed as current versions of PHP<br />';
+			$description .= 'do not support it anymore.<br /><br />';
+			$description .= 'Please check your php-configurations and remove safe_mode-directives to avoid php notices/warnings.';
+		}
+		$question = '';
+
+		eval("\$return.=\"" . getTemplate("update/preconfigitem") . "\";");
+	}
 }
