@@ -44,7 +44,7 @@ function includeFunctions($dirname)
 
 function __autoload($classname)
 {
-	global $libdirname;
+	global $libdirname, $theme;
 	findIncludeClass($libdirname . '/classes/', $classname);
 }
 
@@ -55,7 +55,7 @@ function findIncludeClass($dirname, $classname)
 	{
 		if($filename != '.' && $filename != '..' && $filename != '')
 		{
-			if($filename == 'class.' . $classname . '.php' || $filename == 'abstract.' . $classname . '.php')
+			if($filename == 'class.' . $classname . '.php' || $filename == 'abstract.' . $classname . '.php' || $filename == 'interface.' . $classname . '.php')
 			{
 				include($dirname . $filename);
 				return;
