@@ -12,7 +12,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Language
- * @version    $Id$
+ *
  */
 
 /**
@@ -28,7 +28,7 @@
  */
 function domainHasApsInstances($domainid = 0)
 {
-	global $db, $settings;
+	global $db, $settings, $theme;
 	
 	if($settings['aps']['aps_active'] == '1')
 	{
