@@ -14,7 +14,7 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /**
@@ -34,7 +34,7 @@
 
 function makePathfield($path, $uid, $gid, $fieldType, $value = '', $dom = false)
 {
-	global $lng;
+	global $lng, $theme;
 
 	$value = str_replace($path, '', $value);
 	$field = array();
