@@ -12,12 +12,12 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Settings
- * @version    $Id $
+ *
  */
 
 function buildFormEx($form, $part = '')
 {
-	global $settings;
+	global $settings, $theme;
 	$fields = '';
 
 	if(validateFormDefinition($form))
