@@ -14,12 +14,12 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 function getCustomers($limit_resource = '')
 {
-	global $db;
+	global $db, $theme;
 
 	$additional_conditions = '';
 	$additional_conditions_array = array();
