@@ -26,7 +26,7 @@ if(@php_sapi_name() != 'cli'
 
 class apache_fcgid extends apache
 {
-	protected function composePhpOptions($domain)
+	protected function composePhpOptions($domain, $ssl_vhost = false)
 	{
 		$php_options_text = '';
 
@@ -38,17 +38,26 @@ class apache_fcgid extends apache
 			if((int)$this->settings['phpfpm']['enabled'] == 1)
 			{
 				$php_options_text.= '  SuexecUserGroup "' . $domain['loginname'] . '" "' . $domain['loginname'] . '"' . "\n";
-				$php_options_text.= '  FastCgiExternalServer ' . makeCorrectDir($domain['documentroot']) . $domain['domain'] . "." . 'fpm.external -socket ' . $php->getInterface()->getSocketFile() . ' -user ' . $domain['loginname'] . ' -group ' . $domain['loginname'] . " -idle-timeout " . $this->settings['phpfpm']['idle_timeout'] . "\n";
+				$srvName = 'fpm.external';
+				if ($domain['ssl'] == 1 && $ssl_vhost) {
+					$srvName = 'ssl-fpm.external';
+				}
+				$php_options_text.= '  FastCgiExternalServer ' . $php->getInterface()->getAliasConfigDir() . $srvName . ' -socket ' . $php->getInterface()->getSocketFile() . ' -user ' . $domain['loginname'] . ' -group ' . $domain['loginname'] . " -idle-timeout " . $this->settings['phpfpm']['idle_timeout'] . "\n";
 				$php_options_text.= '  <Directory "' . makeCorrectDir($domain['documentroot']) . '">' . "\n";
 				$php_options_text.= '    <FilesMatch "\.php$">' . "\n";
 				$php_options_text.= '      SetHandler php5-fastcgi'. "\n";
 				$php_options_text.= '      Action php5-fastcgi /fastcgiphp' . "\n";
 				$php_options_text.= '      Options +ExecCGI' . "\n";
 				$php_options_text.= '    </FilesMatch>' . "\n";
-				$php_options_text.= '    Order allow,deny' . "\n";
-				$php_options_text.= '    allow from all' . "\n";
+				// >=apache-2.4 enabled?
+				if ($this->settings['system']['apache24'] == '1') {
+					$php_options_text.= '    Require all granted' . "\n";
+				} else {
+					$php_options_text.= '    Order allow,deny' . "\n";
+					$php_options_text.= '    allow from all' . "\n";
+				}
 				$php_options_text.= '  </Directory>' . "\n";
-				$php_options_text.= '  Alias /fastcgiphp ' . makeCorrectDir($domain['documentroot']) . $domain['domain'] . "." . 'fpm.external' . "\n";
+				$php_options_text.= '  Alias /fastcgiphp ' . $php->getInterface()->getAliasConfigDir() . $srvName . "\n";
 			}
 			else
 			{
@@ -61,26 +70,31 @@ class apache_fcgid extends apache
 				else
 				{
 					$php_options_text.= '  SuexecUserGroup "' . $domain['loginname'] . '" "' . $domain['loginname'] . '"' . "\n";
-					$php_options_text.= '  <Directory "' . $domain['documentroot'] . '">' . "\n";
+					$php_options_text.= '  <Directory "' . makeCorrectDir($domain['documentroot']) . '">' . "\n";
 					$file_extensions = explode(' ', $phpconfig['file_extensions']);
 					$php_options_text.= '    <FilesMatch "\.(' . implode('|', $file_extensions) . ')$">' . "\n";
 					$php_options_text.= '      SetHandler fcgid-script' . "\n";
 					foreach($file_extensions as $file_extension)
 					{
-						$php_options_text.= '      FCGIWrapper ' . $php->getInterface()->getStarterFile() . ' .' . $file_extension . "\n";
+						$php_options_text.= '      FcgidWrapper ' . $php->getInterface()->getStarterFile() . ' .' . $file_extension . "\n";
 					}
 					$php_options_text.= '      Options +ExecCGI' . "\n";
-				        $php_options_text.= '    </FilesMatch>' . "\n";
-					$php_options_text.= '    Order allow,deny' . "\n";
-					$php_options_text.= '    allow from all' . "\n";
+					$php_options_text.= '    </FilesMatch>' . "\n";
+					// >=apache-2.4 enabled?
+					if ($this->settings['system']['apache24'] == '1') {
+						$php_options_text.= '    Require all granted' . "\n";
+					} else {
+						$php_options_text.= '    Order allow,deny' . "\n";
+						$php_options_text.= '    allow from all' . "\n";
+					}
 					$php_options_text.= '  </Directory>' . "\n";
 				}
 			}
 
 			// create starter-file | config-file
 			$php->getInterface()->createConfig($phpconfig);
-			
-			// create php.ini 
+
+			// create php.ini
 			// @TODO make php-fpm support this
 			$php->getInterface()->createIniFile($phpconfig);
 		}
@@ -109,7 +123,7 @@ class apache_fcgid extends apache
 				&& $this->settings['phpfpm']['enabled_ownvhost'] == '1'
 			) {
 				$user = $this->settings['phpfpm']['vhost_httpuser'];
-				$group = $this->settings['phpfpm']['vhost_httpgroup'];	
+				$group = $this->settings['phpfpm']['vhost_httpgroup'];
 			}
 
 			$domain = array(
@@ -120,7 +134,6 @@ class apache_fcgid extends apache
 				'mod_fcgid_maxrequests' => -1,
 				'guid' => $user,
 				'openbasedir' => 0,
-				'safemode' => '0',
 				'email' => $this->settings['panel']['adminmail'],
 				'loginname' => 'froxlor.panel',
 				'documentroot' => $mypath
@@ -129,7 +142,7 @@ class apache_fcgid extends apache
 			// all the files and folders have to belong to the local user
 			// now because we also use fcgid for our own vhost
 			safe_exec('chown -R ' . $user . ':' . $group . ' ' . escapeshellarg($mypath));
-						
+
 			// get php.ini for our own vhost
 			$php = new phpinterface($this->getDB(), $this->settings, $domain);
 
@@ -138,8 +151,8 @@ class apache_fcgid extends apache
 
 			// create starter-file | config-file
 			$php->getInterface()->createConfig($phpconfig);
-			
-			// create php.ini 
+
+			// create php.ini
 			// @TODO make php-fpm support this
 			$php->getInterface()->createIniFile($phpconfig);
 		}
