@@ -17,6 +17,59 @@
  *
  */
 
+//Check Traffic-Lock
+if(function_exists('pcntl_fork')) {
+	$TrafficLock = dirname($lockfile)."/froxlor_cron_traffic.lock";
+	if(file_exists($TrafficLock) &&  is_numeric($TrafficPid=file_get_contents($TrafficLock))) {
+		if(function_exists('posix_kill')) {
+			$TrafficPidStatus = @posix_kill($TrafficPid,0);
+		}
+		else {
+			system("kill -CHLD " . $TrafficPid . " 1> /dev/null 2> /dev/null", $TrafficPidStatus);
+			$TrafficPidStatus = $TrafficPidStatus ? false : true;
+		}
+		if($TrafficPidStatus) {
+			fwrite($debugHandler,"Traffic Run already in progress\n");
+			return 1;
+		}
+	}
+	//Create Traffic Log and Fork
+	// We close the database - connection before we fork, so we don't share resources with the child
+	$db->close();
+	unset($db);
+	$TrafficPid = pcntl_fork();
+	if($TrafficPid) { //Parent
+		file_put_contents($TrafficLock,$TrafficPid);
+		// Recreate the database - connection
+		require ($pathtophpfiles . '/lib/userdata.inc.php');
+		if(isset($sql['root_user']) && isset($sql['root_password']) && (!isset($sql_root) || !is_array($sql_root))) {
+			$sql_root = array(0 => array('caption' => 'Default', 'host' => $sql['host'], 'user' => $sql['root_user'], 'password' => $sql['root_password']));
+			unset($sql['root_user']);
+			unset($sql['root_password']);
+		}
+		$db = new db($sql['host'], $sql['user'], $sql['password'], $sql['db']);
+		return 0;
+	}
+	elseif($TrafficPid == 0) { //Child
+		posix_setsid();
+		fclose($debugHandler);
+		$debugHandler = fopen("/tmp/froxlor_traffic.log","w");
+		require ($pathtophpfiles . '/lib/userdata.inc.php'); //There is no bloody reason not to have sql values in the backend ready!
+		if(isset($sql['root_user']) && isset($sql['root_password']) && (!isset($sql_root) || !is_array($sql_root))) {
+			$sql_root = array(0 => array('caption' => 'Default', 'host' => $sql['host'], 'user' => $sql['root_user'], 'password' => $sql['root_password']));
+			unset($sql['root_user']);
+			unset($sql['root_password']);
+		}
+		$db = new db($sql['host'], $sql['user'], $sql['password'], $sql['db']); //database handler renewal after fork()
+	}
+	else { //Fork failed
+		return 1;
+	}
+}
+else {
+	fwrite($debugHandler,"PHP compiled without pcntl. Not forking traffic-cron, this may take a long time!");
+}
+
 openRootDB($debugHandler, $lockfile);
 require_once(makeCorrectFile(dirname(__FILE__) . '/cron_traffic.inc.functions.php'));
 
@@ -54,7 +107,6 @@ while($row_domainlist = $db->fetch_array($result_domainlist))
 $mysqlusage_all = array();
 $databases = $db->query("SELECT * FROM " . TABLE_PANEL_DATABASES . " ORDER BY `dbserver`");
 $db_root = new db($sql_root[0]['host'], $sql_root[0]['user'], $sql_root[0]['password'], '');
-unset($db_root->password);
 $last_dbserver = 0;
 
 $databases_list = array();
@@ -70,7 +122,6 @@ while($row_database = $db->fetch_array($databases))
 	{
 		$db_root->close();
 		$db_root = new db($sql_root[$row_database['dbserver']]['host'], $sql_root[$row_database['dbserver']]['user'], $sql_root[$row_database['dbserver']]['password'], '');
-		unset($db_root->password);
 		$last_dbserver = $row_database['dbserver'];
 
 		$database_list = array();
@@ -102,16 +153,14 @@ while($row_database = $db->fetch_array($databases))
 
 $db_root->close();
 
-# We are using the file-system quota, this will speed up the diskusage - collection
-if ($settings['system']['diskquota_enabled'])
-{
+// We are using the file-system quota, this will speed up the diskusage - collection
+if ($settings['system']['diskquota_enabled']) {
 	$usedquota = getFilesystemQuota();
 }
 
 $result = $db->query("SELECT * FROM `" . TABLE_PANEL_CUSTOMERS . "` ORDER BY `customerid` ASC");
 
-while($row = $db->fetch_array($result))
-{
+while ($row = $db->fetch_array($result)) {
 	/**
 	 * HTTP-Traffic
 	 */
@@ -119,31 +168,24 @@ while($row = $db->fetch_array($result))
 	fwrite($debugHandler, 'http traffic for ' . $row['loginname'] . ' started...' . "\n");
 	$httptraffic = 0;
 
-	if(isset($domainlist[$row['customerid']])
+	if (isset($domainlist[$row['customerid']])
 	   && is_array($domainlist[$row['customerid']])
-	   && count($domainlist[$row['customerid']]) != 0)
-	{
+	   && count($domainlist[$row['customerid']]) != 0
+	) {
 		// Examining which caption to use for default webalizer stats...
-
-		if($row['standardsubdomain'] != '0')
-		{
+		if ($row['standardsubdomain'] != '0') {
 			// ... of course we'd prefer to use the standardsubdomain ...
-
 			$caption = $domainlist[$row['customerid']][$row['standardsubdomain']];
-		}
-		else
-		{
+		} else {
 			// ... but if there is no standardsubdomain, we have to use the loginname ...
-
 			$caption = $row['loginname'];
 
 			// ... which results in non-usable links to files in the stats, so lets have a look if we find a domain which is not speciallogfiledomain
+			foreach ($domainlist[$row['customerid']] as $domainid => $domain) {
 
-			foreach($domainlist[$row['customerid']] as $domainid => $domain)
-			{
-				if(!isset($speciallogfile_domainlist[$row['customerid']])
-				   || !isset($speciallogfile_domainlist[$row['customerid']][$domainid]))
-				{
+				if (!isset($speciallogfile_domainlist[$row['customerid']])
+				   || !isset($speciallogfile_domainlist[$row['customerid']][$domainid])
+				) {
 					$caption = $domain;
 					break;
 				}
@@ -153,47 +195,60 @@ while($row = $db->fetch_array($result))
 		$httptraffic = 0;
 		reset($domainlist[$row['customerid']]);
 
-		if(isset($speciallogfile_domainlist[$row['customerid']])
+		if (isset($speciallogfile_domainlist[$row['customerid']])
 		   && is_array($speciallogfile_domainlist[$row['customerid']])
-		   && count($speciallogfile_domainlist[$row['customerid']]) != 0)
-		{
+		   && count($speciallogfile_domainlist[$row['customerid']]) != 0
+		) {
 			reset($speciallogfile_domainlist[$row['customerid']]);
-			foreach($speciallogfile_domainlist[$row['customerid']] as $domainid => $domain)
-			{
-				if($settings['system']['mod_log_sql'] == 1)
-				{
-					safeSQLLogfile($domain, $row['loginname']);
-
-					// Remove this domain from the domainlist - it's already analysed
-					// and doesn't need to be selected twice
-
-					unset($domainlist[$row['customerid']][$domainid]);
-				}
-
-				if($settings['system']['awstats_enabled'] == '0')
-				{
+			if ($settings['system']['awstats_enabled'] == '0') {
+				foreach ($speciallogfile_domainlist[$row['customerid']] as $domainid => $domain) {
 					$httptraffic+= floatval(callWebalizerGetTraffic($row['loginname'] . '-' . $domain, $row['documentroot'] . '/webalizer/' . $domain . '/', $domain, $domainlist[$row['customerid']]));
 				}
 			}
 		}
 
-		reset($domainlist[$row['customerid']]);
+		// logrotate speciallogfiles
+		if (isset($speciallogfile_domainlist[$row['customerid']])
+			&& is_array($speciallogfile_domainlist[$row['customerid']])
+			&& count($speciallogfile_domainlist[$row['customerid']]) != 0
+		) {
+			reset($speciallogfile_domainlist[$row['customerid']]);
+			foreach ($speciallogfile_domainlist[$row['customerid']] as $domainid => $domain) {
+				
+				$logrotatefile = '/tmp/froxlor_logrotate_tmpfile.conf';
+				$fh = fopen($logrotatefile, 'w');
 
-		if($settings['system']['mod_log_sql'] == 1)
-		{
-			safeSQLLogfile($domainlist[$row['customerid']], $row['loginname']);
+				$logconf = '# ' . basename($logrotatefile) . "\n" . '# Created ' . date('d.m.Y H:i') . "\n" .
+						$settings['system']['logfiles_directory'] . $row['loginname'] .'-' . $domain . '-access.log ' .
+						$settings['system']['logfiles_directory'] . $row['loginname'] .'-' . $domain . '-error.log {' . "\n" .
+						$settings['system']['logrotate_interval'] . "\n" .
+						'missingok' . "\n" .
+						'rotate ' . $settings['system']['logrotate_keep'] . "\n" .
+						'compress' . "\n" .
+						'delaycompress' . "\n" .
+						'notifempty' . "\n" .
+						'create' . "\n" .
+						'}' . "\n";
+
+				fwrite($fh, $logconf);
+				fclose($fh);
+
+				safe_exec(escapeshellcmd($settings['system']['logrotate_binary']) . ' ' . $logrotatefile);
+
+				fwrite($debugHandler, '   apache::reload: reloading apache' . "\n");
+				safe_exec(escapeshellcmd($settings['system']['apachereload_command']));
+			}
 		}
 
+		reset($domainlist[$row['customerid']]);
+
 		// callAwstatsGetTraffic is called ONLY HERE and
 		// *not* also in the special-logfiles-loop, because the function
 		// will iterate through all customer-domains and the awstats-configs
 		// know the logfile-name, #246
-		if($settings['system']['awstats_enabled'] == '1')
-		{
+		if ($settings['system']['awstats_enabled'] == '1') {
 			$httptraffic+= floatval(callAwstatsGetTraffic($row['customerid'], $row['documentroot'] . '/awstats/', $domainlist[$row['customerid']]));
-		}
-		else
-		{
+		} else {
 			$httptraffic+= floatval(callWebalizerGetTraffic($row['loginname'], $row['documentroot'] . '/webalizer/', $caption, $domainlist[$row['customerid']]));
 		}
 
@@ -201,8 +256,7 @@ while($row = $db->fetch_array($result))
 		makeChownWithNewStats($row);
 		
 		// logrotate
-		if($settings['system']['logrotate_enabled'] == '1')
-		{
+		if ($settings['system']['logrotate_enabled'] == '1') {
 			fwrite($debugHandler, '   logrotate customers logs' . "\n");
 
 			$logrotatefile = '/tmp/froxlor_logrotate_tmpfile.conf';
@@ -233,8 +287,8 @@ while($row = $db->fetch_array($result))
 		 * Webalizer/AWStats might run for some time, so we'd better check if our database is still present
 		 */
 		if (empty($db->link_id)
-		   || $db->link_id === false)
-		{
+		   || $db->link_id === false
+		) {
 			fwrite($debugHandler, 'Database-connection seems to be down, trying to reconnect' . "\n");
 
 			// just in case
@@ -251,7 +305,6 @@ while($row = $db->fetch_array($result))
 
 			fwrite($debugHandler, 'Database-connection re-established' . "\n");
 			unset($sql);
-			unset($db->password);
 			$cronlog->logAction(CRON_ACTION, LOG_WARNING, 'Database-connection crashed during traffic-cronjob, reconnected!');
 		}
 
@@ -264,8 +317,7 @@ while($row = $db->fetch_array($result))
 	fwrite($debugHandler, 'ftp traffic for ' . $row['loginname'] . ' started...' . "\n");
 	$ftptraffic = $db->query_first("SELECT SUM(`up_bytes`) AS `up_bytes_sum`, SUM(`down_bytes`) AS `down_bytes_sum` FROM `" . TABLE_FTP_USERS . "` WHERE `customerid`='" . (int)$row['customerid'] . "'");
 
-	if(!is_array($ftptraffic))
-	{
+	if (!is_array($ftptraffic)) {
 		$ftptraffic = array(
 			'up_bytes_sum' => 0,
 			'down_bytes_sum' => 0
@@ -481,4 +533,7 @@ $db->query('UPDATE `' . TABLE_PANEL_SETTINGS . '` SET `value` = UNIX_TIMESTAMP()
 
 closeRootDB();
 
-?>
+if (function_exists('pcntl_fork')) {
+	@unlink($TrafficLock);
+	die();
+}
